Sys.unsetenv("R_TESTS")
library(testthat)
library(DDD)
library(Rcpp)

test_check("DDD")


